@@ -4,18 +4,9 @@ pub mod codegen;
 pub mod firework_project;
 pub mod parser;
 
-#[macro_export]
-macro_rules! error {
-    ( $( $errors:expr ),+ ) => {{
-        use colored::Colorize;
-        $(
-            println!("{}: {}", "error".red(), $errors.white());
-        )*
-    }};
-
-    () => {};
-}
-
+/// Used when code encounters an unrecoverable error.
+///
+/// Displays all errors given then panics
 #[macro_export]
 macro_rules! unrecoverable_error {
     ( $( $errors:expr ),+ ) => {{
@@ -29,6 +20,9 @@ macro_rules! unrecoverable_error {
     () => {};
 }
 
+/// Used as a placeholder for unfinished code.
+///
+/// Calls the ```unrecoverable_error``` macro for every to-do feature given
 #[macro_export]
 macro_rules! todo_feature {
     ( $( $features:expr ),+ ) => {{
@@ -39,4 +33,7 @@ macro_rules! todo_feature {
 }
 
 #[cfg(test)]
-mod tests {}
+mod tests {
+    mod parser_tests {}
+    mod codegen_tests {}
+}
